==> mythvideo_0.16.orig.tar.gz: mythvideo-0.16/i18n/themestrings.h <==
void strings_null() {
    ThemeUI::tr("Director:");
    ThemeUI::tr("Year:");
    ThemeUI::tr("Rated:");
    ThemeUI::tr("Parental Level:");
    ThemeUI::tr("Browsable:");
    ThemeUI::tr("Runtime:");
    ThemeUI::tr("Plot:");
    ThemeUI::tr("Filename:");
    ThemeUI::tr("Cover File:");
    ThemeUI::tr("IMDB Num.:");
    ThemeUI::tr("SELECT: Edit");
    ThemeUI::tr("");
    ThemeUI::tr("MENU: Options");
    ThemeUI::tr("retrieving data...");
    ThemeUI::tr("[ looking for ]");
    ThemeUI::tr("Enter IMDB #");
    ThemeUI::tr("loading...");
    ThemeUI::tr("No Videos Found");
    ThemeUI::tr("Up/Down, Page Up/Down - Browse");
    ThemeUI::tr("Menu - Options");
    ThemeUI::tr("Parental");
    ThemeUI::tr("Level");
    ThemeUI::tr("1");
    ThemeUI::tr("Directed by");
    ThemeUI::tr("Year");
    ThemeUI::tr("Runtime");
    ThemeUI::tr("User Rating");
    ThemeUI::tr("loading...");
    ThemeUI::tr("No Videos Found");
    ThemeUI::tr("File:");
    ThemeUI::tr("Player:");
    ThemeUI::tr("PL ");
    ThemeUI::tr("1");
    ThemeUI::tr("MythVideo File Associations");
    ThemeUI::tr("Extension:");
    ThemeUI::tr("Command:");
    ThemeUI::tr("Use default player:");
    ThemeUI::tr("Ignore:");
    ThemeUI::tr("Edit Video Information");
    ThemeUI::tr("Name:");
    ThemeUI::tr("Category:");
    ThemeUI::tr("Parental Control:");
    ThemeUI::tr("File to Always Play Next:");
    ThemeUI::tr("Include while Browsing:");
    ThemeUI::tr("Cover Art:");
    ThemeUI::tr("Unique Player Command:");
    ThemeUI::tr("/path/to/the/thing.jpg");
    ThemeUI::tr("Filters video list");
    ThemeUI::tr("Category :");
    ThemeUI::tr("Genre :");
    ThemeUI::tr("Country :");
    ThemeUI::tr("Year :");
    ThemeUI::tr("Runtime :");
    ThemeUI::tr("User Rating :");
    ThemeUI::tr("Browse :");
    ThemeUI::tr("Sort by :");
    ThemeUI::tr("Aucune video");
}

==> mythvideo_0.17.orig.tar.gz: mythvideo-0.17/i18n/themestrings.h <==
void strings_null() {
    ThemeUI::tr("Director:");
    ThemeUI::tr("Year:");
    ThemeUI::tr("Rated:");
    ThemeUI::tr("Parental Level:");
    ThemeUI::tr("Browsable:");
    ThemeUI::tr("Runtime:");
    ThemeUI::tr("Plot:");
    ThemeUI::tr("Filename:");
    ThemeUI::tr("Cover File:");
    ThemeUI::tr("IMDB Num.:");
    ThemeUI::tr("SELECT: Edit");
    ThemeUI::tr("INFO - Action Menu");
    ThemeUI::tr("retrieving data...");
    ThemeUI::tr("[ looking for ]");
    ThemeUI::tr("Enter IMDB #");
    ThemeUI::tr("loading...");
    ThemeUI::tr("No Videos Found");
    ThemeUI::tr("Up/Down, Page Up/Down: Browse   MENU: Options   INFO: Action Menu");
    ThemeUI::tr("Parental");
    ThemeUI::tr("Level");
    ThemeUI::tr("1");
    ThemeUI::tr("Directed by");
    ThemeUI::tr("Year");
    ThemeUI::tr("Runtime");
    ThemeUI::tr("User Rating");
    ThemeUI::tr("loading...");
    ThemeUI::tr("No Videos Found");
    ThemeUI::tr("Directed by");
    ThemeUI::tr("Year");
    ThemeUI::tr("Runtime");
    ThemeUI::tr("User Rating");
    ThemeUI::tr("loading...");
    ThemeUI::tr("No Videos Found");
    ThemeUI::tr("File:");
    ThemeUI::tr("Player:");
    ThemeUI::tr("PL ");
    ThemeUI::tr("1");
    ThemeUI::tr("MythVideo File Associations");
    ThemeUI::tr("Extension:");
    ThemeUI::tr("Command:");
    ThemeUI::tr("Use default player:");
    ThemeUI::tr("Ignore:");
    ThemeUI::tr("Edit Video Information");
    ThemeUI::tr("Name:");
    ThemeUI::tr("Category:");
    ThemeUI::tr("Parental Control:");
    ThemeUI::tr("Play File After This:");
    ThemeUI::tr("File to Always Play Next:");
    ThemeUI::tr("Include while Browsing:");
    ThemeUI::tr("Cover Art:");
    ThemeUI::tr("Unique Player Command:");
    ThemeUI::tr("/path/to/the/thing.jpg");
    ThemeUI::tr("Filters video list");
    ThemeUI::tr("Category :");
    ThemeUI::tr("Genre :");
    ThemeUI::tr("Country :");
    ThemeUI::tr("Year :");
    ThemeUI::tr("Runtime :");
    ThemeUI::tr("User Rating :");
    ThemeUI::tr("Browse :");
    ThemeUI::tr("Sort by :");
    ThemeUI::tr("Aucune video");
}
